#import "AppDelegate.h"
#import "ContactListController.h"
#import "Contact.h"

@implementation AppDelegate

@synthesize window = _window;
@synthesize navigationController = _navigationController;

//----------------------------------------------------
// CALLBACKS
//----------------------------------------------------
- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions
{
    // Init the device window
    self.window = [[UIWindow alloc] initWithFrame:[[UIScreen mainScreen] bounds]];
    
    // NOTE: The "Default.png" open like a SplashScreen
    
    // Load all contacts 
    [self loadContacts];
    
    // Create the contact controller whit all listed contacts
    ContactListController *contactListController = [[ContactListController alloc] init];    
    contactListController.contactList = contactList;
    
    // Create the navigator controller 
    // NOTE: contract controller is a children of navigation controller 
    self.navigationController = [[UINavigationController alloc] initWithRootViewController:contactListController];
    
    // NOTE: navigation controller is a children of device window  
    self.window.rootViewController = self.navigationController;
    self.window.backgroundColor = [UIColor whiteColor];
    
    // Show window
    [self.window makeKeyAndVisible]; 
    
    return YES;
}


//----------------------------------------------------
// METHODS
//----------------------------------------------------
-(void)loadContacts {
    // Alloc on memory
    contactList = [[NSMutableArray alloc] init];
    
    // Find the contacts.plist file
    NSString *plistFilePath = [[NSBundle mainBundle] pathForResource:@"contacts" ofType:@"plist"];
    
    // Transform an plist into dictionary
    NSMutableDictionary *contactsMap = [[NSMutableDictionary alloc] initWithContentsOfFile:plistFilePath];
    
    
    // Add all contacts finded into plist to contact list
    for (NSString *key in contactsMap) {
        NSDictionary *contactMap = [contactsMap objectForKey:key];
        
        // Create an contact by the dictionary
        Contact *contact = [Contact buildWithDictionary:contactMap];
        
        // Add contact model to list
        [contactList addObject:contact];
    }
    
}

@end
