#import "ContactFormController.h"

//----------------------------------------------------
// PRIVATE
//----------------------------------------------------
@interface ContactFormController ()

@end

@implementation ContactFormController
@synthesize delegate;
@synthesize addPictureButton;
@synthesize nameLabel;
@synthesize emailLabel;
@synthesize addressLabel;
@synthesize phoneLabel;
@synthesize siteLabel;
@synthesize twitterLabel;
@synthesize nameField;
@synthesize emailField;
@synthesize addressField;
@synthesize phoneField;
@synthesize siteField;
@synthesize twitterField;
@synthesize keyboardToolbar;

//----------------------------------------------------
// CALLBACKS
//----------------------------------------------------

- (void)viewDidLoad {
    [self setTitle:NSLocalizedString(@"title.add.contact", @"Add contact")];
    
    [nameLabel    setText:NSLocalizedString(@"label.name", @"Name:")];
    [emailLabel   setText:NSLocalizedString(@"label.email", @"E-mail:")];
    [addressLabel setText:NSLocalizedString(@"label.address", @"Address:")];
    [phoneLabel   setText:NSLocalizedString(@"label.phone", @"Phone:")];
    [siteLabel    setText:NSLocalizedString(@"label.site", @"Site:")];
    [siteLabel    setText:NSLocalizedString(@"label.twitter", @"Twitter:")];
    
    // Left side button
    UIBarButtonItem *cancelButton = [[UIBarButtonItem alloc] 
                                  initWithBarButtonSystemItem:UIBarButtonSystemItemCancel 
                                  target: self 
                                  action: @selector(navigationCancelForm)];
    self.navigationItem.leftBarButtonItem = cancelButton;
    
    // Right side button
    UIBarButtonItem *confirmButton = [[UIBarButtonItem alloc] 
                                  initWithBarButtonSystemItem:UIBarButtonSystemItemSave 
                                  target: self 
                                  action: @selector(navigationConfirmForm)];
    self.navigationItem.rightBarButtonItem = confirmButton;
    
    
    // Init the keyboard toolbar controller
    [self loadKeyboardToolbar];
}

- (void)viewDidUnload {
    // Best pratices
    [self setNameField:nil];
    [self setEmailField:nil];
    [self setAddressField:nil];
    [self setPhoneField:nil];
    [self setSiteField:nil];
    [self setNameLabel:nil];
    [self setEmailLabel:nil];
    [self setAddressLabel:nil];
    [self setPhoneLabel:nil];
    [self setSiteLabel:nil];
    [self setTwitterLabel:nil];
    [self setTwitterField:nil];
    [self setKeyboardToolbar:nil];
    [self setAddPictureButton:nil];
    [super viewDidUnload];
}


//----------------------------------------------------
// NAVIGATION ACTIONS
//----------------------------------------------------

- (void) navigationCancelForm{
    // Return to parent view
    [self dismissModalViewControllerAnimated:YES];
}

- (void) navigationConfirmForm{
    Contact *contact = [[Contact alloc] init];
    [contact setName:    self.nameField.text];
    [contact setEmail:   self.emailField.text];
    [contact setAddress: self.addressField.text];
    [contact setPhone:   self.phoneField.text];
    [contact setSite:    self.siteField.text];
    [contact setTwitter: self.twitterField.text];
    
    [delegate createContact:contact];

    // Return to parent view
    [self dismissModalViewControllerAnimated:YES];
}

//----------------------------------------------------
// METHODS
//----------------------------------------------------

- (void) loadKeyboardToolbar {
    // KeyboardToolbar button
    UIBarButtonItem *okButton = [[UIBarButtonItem alloc] 
                                 initWithBarButtonSystemItem:UIBarButtonSystemItemDone
                                 target: self 
                                 action: @selector(hideKeyboardToolbar)];
    // Keyboard Toolbar
    [self.keyboardToolbar setItems:[[NSArray alloc] initWithObjects:okButton, nil]];
}

- (IBAction) showKeyboardToolbar {
    [keyboardToolbar setHidden:NO];
    [UIView transitionWithView:keyboardToolbar
                    duration:0.25f 
                    options:UIViewAnimationCurveEaseInOut
                    animations:^(void) {
                        keyboardToolbar.center = CGPointMake(160.0F, 180.0F);
                    } 
                    completion:^(BOOL finished) {
                        // Nothing
                    }
     ]; 
}

- (void) hideKeyboardToolbar {
    // Lost focus for all UITextField
    [self.nameField    resignFirstResponder];
    [self.emailField   resignFirstResponder];
    [self.addressField resignFirstResponder];
    [self.phoneField   resignFirstResponder];
    [self.emailField   resignFirstResponder];
    [self.twitterField resignFirstResponder];
    
    [UIView transitionWithView:keyboardToolbar
                    duration:0.3f 
                    options:UIViewAnimationCurveEaseInOut
                    animations:^(void) {
                        keyboardToolbar.center = CGPointMake(160.0F, 495.0F);
                    } 
                    completion:^(BOOL finished) {
                        [keyboardToolbar setHidden:YES];
                        keyboardToolbar.center = CGPointMake(160.0F, 395.0F);
                    }
     ]; 
}

- (IBAction)actionSelectPicture:(id)sender {
    
    if([UIImagePickerController isSourceTypeAvailable:UIImagePickerControllerSourceTypeCamera]){
            
        UIActionSheet *sheet = [[UIActionSheet alloc] initWithTitle:@"Choose contact picture" delegate:self cancelButtonTitle:@"Cancel" destructiveButtonTitle:nil otherButtonTitles:@"Take Picture", @"Choose Picture", nil];
        [sheet showInView:self.view];
        
    } else {
        
        UIImagePickerController *picker = [[UIImagePickerController alloc] init];
        picker.sourceType = UIImagePickerControllerSourceTypePhotoLibrary;
        picker.allowsEditing = YES;
        picker.delegate = self;
        [self presentModalViewController:picker animated:YES];
        
    }
    
}

//----------------------------------------------------
// DELEGATE METHODS
//----------------------------------------------------


- (void)actionSheet:(UIActionSheet *)actionSheet didDismissWithButtonIndex:(NSInteger)buttonIndex {
    
    UIImagePickerController *picker = [[UIImagePickerController alloc] init];
    picker.delegate = self;
    picker.allowsEditing = YES;
    
    switch (buttonIndex) {
        case 0:
            picker.sourceType = UIImagePickerControllerSourceTypeCamera;
            break;
            
        case 1:
            picker.sourceType = UIImagePickerControllerSourceTypePhotoLibrary;
            break;            
            
        default:
            return;
    }
    
    [self presentModalViewController:picker animated:YES];
}

- (void)imagePickerController:(UIImagePickerController *)picker didFinishPickingMediaWithInfo:(NSDictionary *)info {
        
    UIImage *selectedImage = [info valueForKey:UIImagePickerControllerEditedImage];
    [addPictureButton setImage:selectedImage forState:UIControlStateNormal];
    [picker dismissModalViewControllerAnimated:YES];
    
}
@end
