#import <MessageUI/MFMailComposeViewController.h>
#import <MessageUI/MFMessageComposeViewController.h>
#import "ContactListController.h"
#import "ContactFormController.h"
#import "EditContactFormControllerViewController.h"
#import "AppDelegate.h"
#import "Contact.h"

@interface ContactListController()

- (void)gesturesListenner:(UIGestureRecognizer *)gestureRecognizer;
- (void)call;
- (void)sendMail;
- (void)sendSMS;
- (void)openSite;
- (void)showMap;

- (void)appWithOpenURL:(NSString *)url;

@end

@implementation ContactListController
@synthesize contactList;

//----------------------------------------------------
// CALLBACKS
//----------------------------------------------------

-(void) viewDidLoad{
    // Set Navigation Title
    [self setTitle:NSLocalizedString(@"title.contacts", @"Contact")];
    
    // Create an button "add like" and add it to right side of navigation panel
    UIBarButtonItem *addButton = [[UIBarButtonItem alloc] 
                                  initWithBarButtonSystemItem:UIBarButtonSystemItemAdd 
                                        target:self action:@selector(navigationShowForm)];
    self.navigationItem.rightBarButtonItem = addButton;
    
    // Create an button "edit like"(default in all views) 
    // and add it to the right side of navigation panel
    self.navigationItem.leftBarButtonItem = self.editButtonItem;
    
    
    // Create an gesture recognizer
    UILongPressGestureRecognizer *gestureRecognizer = [[UILongPressGestureRecognizer alloc] 
                                             initWithTarget:self 
                                             action:@selector(gesturesListenner:)];
    // Add the gesture recognizer to my tableView
    [self.tableView addGestureRecognizer: gestureRecognizer];    
    
    sleep(0.5);
}

// NOTE: Section is an group of list
-(NSInteger)numberOfSectionsInTableView:(UITableView *)tableView{
    return 1;
}

// NOTE: Rownum position is relative from your Section
-(NSInteger) tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section{
    return [contactList count];
}

// NOTE: Manage the table cells
-(UITableViewCell *) tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath{
    
    // NOTE: Trick to manage device memory
    // Allocating only necessary number of rows that can be displayed
    static NSString *CellIdentifier = @"Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    
    if(cell == nil){
        // Create an cell with identifier 
        cell = [[UITableViewCell alloc] 
                initWithStyle:UITableViewCellStyleSubtitle 
                reuseIdentifier:CellIdentifier];
        
        // Add an right side arrow on cell
        [cell setAccessoryType:UITableViewCellAccessoryDisclosureIndicator];
    }
        
    Contact *c = [contactList objectAtIndex:[indexPath row]];
    cell.textLabel.text = c.name;
    cell.detailTextLabel.text = c.email;
    
    return cell;
}


// Remove tableView line method
- (void) tableView:(UITableView *)tableView 
    commitEditingStyle:(UITableViewCellEditingStyle)editingStyle 
    forRowAtIndexPath:(NSIndexPath *)indexPath {
    
    // If is delete..
    if(editingStyle == UITableViewCellEditingStyleDelete){
        [contactList removeObjectAtIndex:indexPath.row];
        [tableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] 
                         withRowAnimation:UITableViewRowAnimationFade];
    }
    
}

// Reorder table rows
- (void) tableView:(UITableView *)tableView 
        moveRowAtIndexPath:(NSIndexPath *)sourceIndexPath 
        toIndexPath:(NSIndexPath *)destinationIndexPath {
    
    Contact *contact = [contactList objectAtIndex: sourceIndexPath.row];
    [contactList removeObjectAtIndex:sourceIndexPath.row];
    [contactList insertObject:contact atIndex:destinationIndexPath.row];
        
}

// Enable row edition
- (void) tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    Contact *contact = [contactList objectAtIndex:indexPath.row];
    EditContactFormControllerViewController *editFormController = [[EditContactFormControllerViewController alloc] initWithContact:contact];
    editFormController.delegate = self;
    
    [self.navigationController pushViewController:editFormController animated:YES];
}

//----------------------------------------------------
// NAVIGATION ACTIONS
//----------------------------------------------------

- (void) navigationShowForm {
    // Init method enables XIB with same name of controller
    ContactFormController *formController = [[ContactFormController alloc] init];

    // Animations
    [formController setModalTransitionStyle:UIModalTransitionStyleCrossDissolve];
    
    // Indicate who is the delegate
    [formController setDelegate: self];
    
    
    // Add the navigator controller
    UINavigationController *navigationController = [[UINavigationController alloc] initWithRootViewController:formController];
    
    // Move to the next view
    [self presentModalViewController:navigationController animated:YES];
}

//----------------------------------------------------
// METHODS
//----------------------------------------------------

- (void) gesturesListenner:(UIGestureRecognizer *)gestureRecognizer {
    
    // Gestures has 4 steps:
    // Lets get the first
    if(gestureRecognizer.state == UIGestureRecognizerStateBegan){
        
        // Localize the gesture location on tableView
        CGPoint location = [gestureRecognizer locationInView: self.tableView];
        
        // Get the IndexPath from location
        NSIndexPath *path = [self.tableView indexPathForRowAtPoint:location];
        
        // Get the Contact from IndexPath
        selectedContact = [contactList objectAtIndex: path.row];
        
        
        // Show an actionSheet
        UIActionSheet *sheet = [[UIActionSheet alloc] initWithTitle:selectedContact.name delegate:self cancelButtonTitle:@"Cancel" destructiveButtonTitle:nil otherButtonTitles:@"Call", @"Send Mail", @"SMS", @"View Site", @"Open Map", nil];
        [sheet showInView:self.view];
        
    }
    
}

- (void) call {
    NSLog(@"CALL");
    
    // Get current device
    UIDevice *device = [UIDevice currentDevice];
    if([device.model isEqualToString:@"iPhone"]){ // If device is iPhone
        
        NSString *phoneNumber = [NSString stringWithFormat:@"tel:%@", selectedContact.phone];
        [self appWithOpenURL:phoneNumber];  
        
    } else { // Can't call
        
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Ops!" message:@"This device unsupport this feature" delegate:nil cancelButtonTitle:@"Ok" otherButtonTitles:nil];
        [alert show];
        
    }
    
}

- (void) sendMail {
    NSLog(@"MAIL");   
    
    if([MFMailComposeViewController canSendMail]){
        
        MFMailComposeViewController *sender = [[MFMailComposeViewController alloc] init];
        sender.mailComposeDelegate =self;
        
        [sender setToRecipients:[NSArray arrayWithObject:selectedContact.email]];
        [sender setSubject:@"Caelum"];
        
        [self presentModalViewController:sender animated:YES];
        
    } else {
        
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Ops!" message:@"You can't send email" delegate:nil cancelButtonTitle:@"Ok" otherButtonTitles: nil];
        [alert show];
        
    }
    
}

- (void) sendSMS {
    NSLog(@"SMS");   
    
    if([MFMessageComposeViewController canSendText]){
        
        MFMessageComposeViewController *sender = [[MFMessageComposeViewController alloc] init];
        sender.messageComposeDelegate = self;
        
        [sender setTitle:@"Caelum SMS"];
        [sender setRecipients:[NSArray arrayWithObject:selectedContact.phone]];   
        
        [self presentModalViewController:sender animated:YES];
        
    } else {
        
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Ops!" message:@"You can't send message" delegate:nil cancelButtonTitle:@"Ok" otherButtonTitles: nil];
        [alert show];
        
    }
    
}

- (void) openSite {
    NSLog(@"SITE");
    NSString *site = selectedContact.site;
    [self appWithOpenURL:site];
}

- (void) showMap {
    NSLog(@"MAP");    
    NSString *url = [[NSString stringWithFormat:@"http://maps.google.com/maps?q=%@", selectedContact.address] stringByAddingPercentEscapesUsingEncoding:NSUTF8StringEncoding];
    [self appWithOpenURL:url];
}

- (void) appWithOpenURL:(NSString *)url {
    // This method open installed applications on device
    [[UIApplication sharedApplication] openURL:[NSURL URLWithString:url]];
}

//----------------------------------------------------
// PROTOCOL IMPLEMENTATIONS
//----------------------------------------------------

- (void) createContact: (Contact *) contact {
    [contactList addObject:contact];
    // Simple reload
    [self.tableView reloadData];
}

- (void) updateContactSuccess {
    // Simple reload
    [self.tableView reloadData];
}

- (void) actionSheet:(UIActionSheet *)actionSheet clickedButtonAtIndex:(NSInteger)buttonIndex {
    switch (buttonIndex) {
        case 0:
            [self call];
            break;
            
        case 1:
            [self sendMail];
            break;
            
        case 2:
            [self sendSMS];
            break;

        case 3:
            [self openSite];
            break;
            
        case 4:
            [self showMap];
            break;
            
        default:
            break;
    }
}

// Hide email form
- (void)mailComposeController:(MFMailComposeViewController *)controller didFinishWithResult:(MFMailComposeResult)result error:(NSError *)error {
    [self dismissModalViewControllerAnimated:YES];
}

// Hide message form
- (void)messageComposeViewController:(MFMessageComposeViewController *)controller didFinishWithResult:(MessageComposeResult)result {
    [self dismissModalViewControllerAnimated:YES];
}

  
@end
